# -*- coding:utf-8 -*-

'''
		Este é o arquivo de setup do modulo "printList.py"
		não mude nenhuma linha deste arquivo isso podera
		comprometer a instalação do modulo.
		
		@Author: Jimmie Haskell
		@Date 27/11/2015
		@email: haskell4228@gmail.com
'''

from distutils.core import setup

setup(
	name 					= 'plst',
	version 			= '1.1.0',
	py_modules 		= ['plst'],
	author 				= 'Jimmie Haskell',
	author_email 	= 'haskell4228@gmail.com',
	url 					= 'http://www.facebook.com/jimmiehaskell',
	description 	='A simple function that prints nested lists.',
)




# -*- coding:utf-8 -*-

'''

		Este é o modulo "printList.py" ele fornece uma
		função onde pode ou não imprimir uma ou varias
		listas aninhadas.
		
		@Author: Jimmie Haskell
		@Date 27/11/2015
		@email: haskell4228@gmail.com	
			
'''

from __future__ import print_function

def printList(theList, listSpace) :
	for eachList in theList :
		if isinstance(eachList, list) :
			printList(eachList, listSpace+1)
		else :
			for tab in range(listSpace) :
				print("\t", end='')
			print(eachList)
